@@ -72,8 +72,8 @@
 #include "md5sig.h"
 #endif
 
-#define BV_VERSION	"0.37Beta"
-#define BV_COPYRIGHT	"Copyright (c) 1998-2002 Internet Initiative Japan Inc.\r\nCopyright (c) 2003-2005 Intec NetCore, Inc."
+#define BV_VERSION	"0.38Beta"
+#define BV_COPYRIGHT	"Copyright (c) 1998-2002 Internet Initiative Japan Inc.\r\nCopyright (c) 2003-2005 Intec NetCore, Inc.\nBugest-Network"
 
 /* BGP Header Type field defines */
 #define BGPTYPES                5
@@ -146,7 +146,7 @@
 #define CAP_4OCTAS			65	/* Chen    */
 #define CAP_DCAP			66	/* Chen    */
 
-/* Err Codes */
+/* Notification Err Codes */
 #define MESSAGE_HEADER_ERROR		1
 #define OPEN_MESSAGE_ERROR		2
 #define UPDATE_MESSAGE_ERROR		3
@@ -154,10 +154,12 @@
 #define FINITE_STATE_MACHINE_ERROR	5
 #define CEASE				6
 
+/* Notification ErrCodes : Message Header Error subcodes */
 #define CONNECTION_NOT_SYNCRONIZED	1
 #define BAD_MESSAGE_LENGTH		2
 #define BAD_MESSAGE_TYPE		3
 
+/* Notification ErrCodes : OPEN Message Error subcodes */
 #define UNSUPPORTED_VERSION_NUMBER	1
 #define BAD_PEER_AS			2
 #define BAD_BGP_IDENTIFIER		3
@@ -166,6 +168,7 @@
 #define UNACCEPTABLE_HOLD_TIME		6
 #define UNSUPPORTED_CAPABILITY		7	/* RFC2842 */
 
+/* Notification ErrCodes : UPDATE Message Error subcodes */
 #define MALFORMED_ATTRIBUTE_LIST	1
 #define UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE	2
 #define MISSING_WELL_KNOWN_ATTRIBUTE	3
@@ -260,6 +263,8 @@ typedef struct {
 	char		*data;			/* Recv Data */
 	int		holdtimer;		/* Hold Timer Value */
 	int		keepalive;		/* Keepalive Timer Value */
+	int		holdtimer_conf;		/* Configured Hold Timer */
+	int		keepalive_conf;		/* Configured Keepalive Timer */
 	char		logname[FNAMESIZE];	/* Log File Name */
 	u_char		logtype;		/* Logging Type */
 	boolean		status_notify;		/* statys notify flag */
