@@ -625,10 +625,17 @@ int pn;
 	return sz;
 }
 
-int sendnotification(pn, ec, sc)
-int pn;
-char ec;
-char sc;
+/********************************************************
+ * Send Notification Message                            *
+ *------------------------------------------------------*
+ * pn : Peer Number                                     *
+ * ec : Error Code                                      *
+ * sc : Sub Error Code                                  *
+ *------------------------------------------------------*
+ * Return:                                              *
+ *  Send Status. It equal with sockwrite function       *
+ ********************************************************/
+int sendnotification(int pn, char ec, char sc)
 {
 	char	buf[256];
 	int	sz;
