@@ -174,8 +174,7 @@ char capability_check(char *param, char length, int pn)
 }
 
 
-int openerrchk(pn)
-int pn;
+int openerrchk(int pn)
 {
 	u_short	bv;
 	char	*ptr;
@@ -266,8 +265,8 @@ int pn;
 	close(peer[pn].soc);
 	FD_CLR(peer[pn].soc, &readfds);
 	peer[pn].soc 	 = -1;
-	peer[pn].holdtimer = HOLD_TIMER;
-	peer[pn].keepalive = KEEPALIVE_TIMER;
+	peer[pn].holdtimer = peer[pn].holdtimer_conf;
+	peer[pn].keepalive = peer[pn].keepalive_conf;
 	if (peer[pn].peerstatus == true) {
 	    /* timer_value.tv_sec = RE_INITIAL_TIMER; */
 	    timer_value.tv_sec = peer[pn].session_re_init_timer;
@@ -584,6 +583,10 @@ int check_fsm(int peer_num)
 				ptr = peer[peer_num].data;
 				/* Get Hold Timer Value */
 				peer[peer_num].holdtimer = buf2ushort(ptr+3);
+				if (peer[peer_num].holdtimer != 0) {
+					peer[peer_num].keepalive = 
+						(int)(peer[peer_num].holdtimer/3);
+				}
 
 				/* Timer Set */
 				if (peer[peer_num].holdtimer > 0) {
@@ -720,14 +723,21 @@ int check_fsm(int peer_num)
 			peer[peer_num].event = BGP_NONE;
 			break;
 		case HOLD_TIME_EXP:
+			/**** Hold Timer Expired then Clear Peer ***/
+			/* NOTIFICATION Message sent */
+			sendnotification(peer_num, HOLD_TIME_EXPIERD, 0);
+			clear_peer(peer_num);
+
+			/************* BUG!! Delete *************
 			timer_value.tv_sec = peer[peer_num].holdtimer - 2;
 			timer_value.tv_usec = 0;
 			(void)entry_timer(&timer_value, peer[peer_num].neighbor,
-					ID_HOLD_TIMER);		/* XXX */
+					ID_HOLD_TIMER);		/* XXX
 
-			/* KEEPALIVE Message sent */
+			/* KEEPALIVE Message sent 
 			sendkeepalive(peer_num);
 			peer[peer_num].event = BGP_NONE;
+			*********************************************/
 			break;
 		case RECV_KEEPALIVE:
 			/* Restart Hold timer */
@@ -742,6 +752,13 @@ int check_fsm(int peer_num)
 			peer[peer_num].event = BGP_NONE;
 			break;
 		case RECV_UPDATE:
+			/* Restart Hold timer */
+			off_timer(peer[peer_num].neighbor, ID_HOLD_TIMER);
+			timer_value.tv_sec = peer[peer_num].holdtimer - 2;
+			timer_value.tv_usec = 0;
+			(void)entry_timer(&timer_value, peer[peer_num].neighbor,
+					ID_HOLD_TIMER);		/* XXX */
+
 			/* Process UPDATE */
 			if (1) {
 				/* Process UPDATE is OK */
